package org.jeecg.modules.tbSpecs.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.tbSpecs.entity.TbSpecs;
import org.jeecg.modules.tbSpecs.service.ITbSpecsService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: tb_specs
 * @Author: jeecg-boot
 * @Date:   2024-12-13
 * @Version: V1.0
 */
@Api(tags="tb_specs")
@RestController
@RequestMapping("/tbSpecs/tbSpecs")
@Slf4j
public class TbSpecsController extends JeecgController<TbSpecs, ITbSpecsService> {
	@Autowired
	private ITbSpecsService tbSpecsService;
	
	/**
	 * 分页列表查询
	 *
	 * @param tbSpecs
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "tb_specs-分页列表查询")
	@ApiOperation(value="tb_specs-分页列表查询", notes="tb_specs-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<TbSpecs>> queryPageList(TbSpecs tbSpecs,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<TbSpecs> queryWrapper = QueryGenerator.initQueryWrapper(tbSpecs, req.getParameterMap());
		Page<TbSpecs> page = new Page<TbSpecs>(pageNo, pageSize);
		IPage<TbSpecs> pageList = tbSpecsService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param tbSpecs
	 * @return
	 */
	@AutoLog(value = "tb_specs-添加")
	@ApiOperation(value="tb_specs-添加", notes="tb_specs-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody TbSpecs tbSpecs) {
		tbSpecsService.save(tbSpecs);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param tbSpecs
	 * @return
	 */
	@AutoLog(value = "tb_specs-编辑")
	@ApiOperation(value="tb_specs-编辑", notes="tb_specs-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody TbSpecs tbSpecs) {
		tbSpecsService.updateById(tbSpecs);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "tb_specs-通过id删除")
	@ApiOperation(value="tb_specs-通过id删除", notes="tb_specs-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		tbSpecsService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "tb_specs-批量删除")
	@ApiOperation(value="tb_specs-批量删除", notes="tb_specs-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.tbSpecsService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "tb_specs-通过id查询")
	@ApiOperation(value="tb_specs-通过id查询", notes="tb_specs-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<TbSpecs> queryById(@RequestParam(name="id",required=true) String id) {
		TbSpecs tbSpecs = tbSpecsService.getById(id);
		if(tbSpecs==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(tbSpecs);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param tbSpecs
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, TbSpecs tbSpecs) {
        return super.exportXls(request, tbSpecs, TbSpecs.class, "tb_specs");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, TbSpecs.class);
    }

}
